@@ -35,6 +35,7 @@ BinaryClock::BinaryClock(QObject *parent, const QVariantList &args)
       m_time(0, 0)
 {
     KGlobal::locale()->insertCatalog("libplasmaclock");
+    KGlobal::locale()->insertCatalog("timezones4");
 
     setHasConfigurationInterface(true);
     resize(getWidthFromHeight(128), 128);
@@ -97,6 +98,7 @@ void BinaryClock::constraintsEvent(Plasma::Constraints constraints)
 
         } else {
             resize(getWidthFromHeight((int) contentsRect().height()) + borderWidth, contentsRect().height() + borderHeight);
+            emit appletTransformedItself();
         }
     }
 }
@@ -267,13 +269,9 @@ void BinaryClock::paintInterface(QPainter *p, const QStyleOptionGraphicsItem *op
     int yPos = ((appletHeight - 4 * rectSize) / 2) + contentsRect.topLeft().y();
     int xPos = ((appletWidth - (rectSize * dots) - 5) / 2) + contentsRect.topLeft().x();
 
-    const QString hours = m_time.toString("HH");
-    const QString minutes = m_time.toString("mm");
-    const QString seconds = m_time.toString("ss");
-
-    char timeDigits[6] = {hours[0].toAscii(), hours[1].toAscii(),
-                          minutes[0].toAscii(), minutes[1].toAscii(),
-                          seconds[0].toAscii(), seconds[1].toAscii()};
+    char timeDigits[6] = {m_time.hour() / 10, m_time.hour() % 10,
+                          m_time.minute() / 10, m_time.minute() % 10,
+                          m_time.second() / 10, m_time.second() % 10};
 
     for (int i = 0; i < dots; i++) {
         for (int j = 0; j < 4; j++) {
