@@ -20,45 +20,22 @@
 #include "Places.h"
 #include <KRun>
 #include <KLocalizedString>
-#include <KDebug>
 #include <KIcon>
+#include <KStandardDirs>
 
 namespace Models {
 
 Places::Places()
-    : BaseModel(true)
+    : XbelModel(
+            KStandardDirs::locateLocal("data", "kfileplaces/bookmarks.xml")
+            )
 {
-    load();
+    setSelfTitle(i18n("Places"));
+    setSelfIcon(KIcon("folder"));
 }
 
 Places::~Places()
 {
 }
 
-void Places::load()
-{
-    // We don't want to use addUrl, because of the icons
-    add(
-        i18n("Home Folder"),
-        getenv("HOME"),
-        KIcon("user-home"),
-        getenv("HOME")
-    );
-
-    add(
-        i18n("Root Folder"),
-        "/",
-        KIcon("folder-red"),
-        "/"
-    );
-
-    add(
-        i18n("Network Folders"),
-        "remote:/",
-        KIcon("folder-remote"),
-        "remote:/"
-    );
-
-}
-
 } // namespace Models
