@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOT_FULL_BORDER_LAYOUT_H_
-#define LANCELOT_FULL_BORDER_LAYOUT_H_
+#ifndef LANCELOT_FULL_BORDER_LAYOUT_H
+#define LANCELOT_FULL_BORDER_LAYOUT_H
 
 #include <lancelot/lancelot_export.h>
 
@@ -114,13 +114,13 @@ public:
      *
      * @param border border for which the size is requested
      */
-    qreal size(Border border);
+    qreal size(Border border) const;
 
-    L_Override virtual void setGeometry(const QRectF & rect);
-    L_Override virtual int count() const;
-    L_Override virtual QGraphicsLayoutItem * itemAt(int i) const;
-    L_Override virtual void removeAt(int index);
-    L_Override virtual QSizeF sizeHint(Qt::SizeHint which,
+    L_Override void setGeometry(const QRectF & rect);
+    L_Override int count() const;
+    L_Override QGraphicsLayoutItem * itemAt(int i) const;
+    L_Override void removeAt(int index);
+    L_Override QSizeF sizeHint(Qt::SizeHint which,
             const QSizeF & constraint = QSizeF()) const;
 
 private:
@@ -130,5 +130,5 @@ private:
 
 } // namespace Lancelot
 
-#endif /* LANCELOT_FULL_BORDER_LAYOUT_H_ */
+#endif /* LANCELOT_FULL_BORDER_LAYOUT_H */
 
