@@ -17,8 +17,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-#ifndef LANCELOT_SCROLL_PANE_H_
-#define LANCELOT_SCROLL_PANE_H_
+#ifndef LANCELOT_SCROLL_PANE_H
+#define LANCELOT_SCROLL_PANE_H
 
 #include <lancelot/lancelot_export.h>
 
@@ -68,7 +68,7 @@ public:
      *                  size is needed
      * @returns scroll unit size
      */
-    virtual qreal scrollUnit(Qt::Orientation direction) = 0;
+    virtual qreal scrollUnit(Qt::Orientation direction) const = 0;
 
     /**
      * Sets the scroll pane that contains this Scrollable
@@ -167,10 +167,11 @@ public:
      */
     void scrollTo(QRectF rect);
 
-    L_Override virtual void setGeometry(const QRectF & rect);
-    L_Override virtual void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
-    L_Override virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
-    L_Override virtual void wheelEvent(QGraphicsSceneWheelEvent * event);
+protected:
+    L_Override void hoverEnterEvent(QGraphicsSceneHoverEvent * event);
+    L_Override void hoverLeaveEvent(QGraphicsSceneHoverEvent * event);
+    L_Override void wheelEvent(QGraphicsSceneWheelEvent * event);
+    L_Override void resizeEvent(QGraphicsSceneResizeEvent * event);
 
 public Q_SLOTS:
     /**
@@ -198,5 +199,5 @@ private:
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(Lancelot::ScrollPane::Flags)
 
-#endif // LANCELOT_SCROLL_PANE_H_
+#endif // LANCELOT_SCROLL_PANE_H
 
