@@ -1,5 +1,6 @@
 /*
  *   Copyright 2007,2008 by Alex Merry <alex.merry@kdemail.net>
+ *   Copyright 2008 by Tony Murray <murraytony@gmail.com>
  *
  *   Some code (text size calculation) taken from clock applet:
  *   Copyright 2007 by Sebastian Kuegler <sebas@kde.org>
@@ -59,14 +60,14 @@ NowPlaying::NowPlaying(QObject *parent, const QVariantList &args)
 
     connect(this, SIGNAL(metadataChanged(QMap<QString,QString>)),
             m_textPanel, SLOT(updateMetadata(QMap<QString,QString>)));
+    connect(this, SIGNAL(coverChanged(QPixmap)),
+            m_textPanel, SLOT(updateArtwork(QPixmap)));
 
     m_volumeSlider->setOrientation(Qt::Vertical);
     m_volumeSlider->setMinimum(0);
     m_volumeSlider->setMaximum(100);
     m_volumeSlider->setValue(0);
-    connect(this, SIGNAL(volumeChanged(int)),
-            m_volumeSlider, SLOT(setValue(int)));
-    connect(m_volumeSlider, SIGNAL(sliderMoved(int)),
+    connect(m_volumeSlider, SIGNAL(valueChanged(int)),
             this, SLOT(setVolume(int)));
     m_volumeSlider->setEnabled(false);
 
@@ -74,11 +75,7 @@ NowPlaying::NowPlaying(QObject *parent, const QVariantList &args)
     m_positionSlider->setMinimum(0);
     m_positionSlider->setMaximum(0);
     m_positionSlider->setValue(0);
-    connect(this, SIGNAL(positionChanged(int)),
-            m_positionSlider, SLOT(setValue(int)));
-    connect(this, SIGNAL(lengthChanged(int)),
-            m_positionSlider, SLOT(setMaximum(int)));
-    connect(m_positionSlider, SIGNAL(sliderMoved(int)),
+    connect(m_positionSlider, SIGNAL(valueChanged(int)),
             this, SLOT(setPosition(int)));
     m_positionSlider->setEnabled(false);
 }
@@ -126,6 +123,8 @@ void NowPlaying::layoutPlanar()
         setAspectRatioMode(Plasma::IgnoreAspectRatio);
         setMinimumSize(300, 200);
 
+        Plasma::ToolTipManager::self()->unregisterWidget(this);
+
         QGraphicsGridLayout* layout = new QGraphicsGridLayout();
         m_textPanel->show();
         layout->addItem(m_textPanel, 0, 0);
@@ -160,6 +159,8 @@ void NowPlaying::layoutHorizontal()
         kDebug() << "Button Panel Minimum Size:" << m_buttonPanel->minimumSize();
         layout->addItem(m_buttonPanel);
 
+        Plasma::ToolTipManager::self()->registerWidget(this);
+
         kDebug() << "Minimum size before changing layout" << minimumSize();
         kDebug() << "Preferred size before changing layout" << preferredSize();
         setLayout(layout);
@@ -236,10 +237,13 @@ void NowPlaying::dataUpdated(const QString &name,
     int length = data["Length"].toInt();
     if (length != m_length) {
         m_length = length;
+
+        m_positionSlider->blockSignals(true);
         if (length == 0) {
-            emit positionChanged(0);
+            m_positionSlider->setValue(0);
         }
-        emit lengthChanged(m_length);
+        m_positionSlider->setMaximum(length);
+        m_positionSlider->blockSignals(false);
     }
     if (length != 0) {
         int pos = data["Position"].toInt();
@@ -248,7 +252,9 @@ void NowPlaying::dataUpdated(const QString &name,
                    QString::number(length / 60) + ':' +
                    QString::number(length % 60).rightJustified(2, '0');
         // we assume it's changed
-        emit positionChanged(pos);
+        m_positionSlider->blockSignals(true);
+        m_positionSlider->setValue(pos);
+        m_positionSlider->blockSignals(false);
     }
 
     QMap<QString,QString> metadata;
@@ -267,23 +273,41 @@ void NowPlaying::dataUpdated(const QString &name,
 
     if (data["Volume"].toDouble() != m_volume) {
         m_volume = data["Volume"].toDouble();
-        emit volumeChanged(m_volume * 100);
+        m_volumeSlider->blockSignals(true);
+        m_volumeSlider->setValue(m_volume * 100);
+        m_volumeSlider->blockSignals(false);
     }
 
     // used for seeing when the track has changed
-    QString track = metadata["Artist"] + " - " + metadata["Title"];
-
-    // assume the artwork didn't change unless the track did
-    if (track != m_track) {
-        m_track = track;
+    if ((metadata["Title"] != m_title) || (metadata["Artist"] != m_artist))
+    {
+        m_title = metadata["Title"];
+        m_artist = metadata["Artist"];
 
         m_artwork = data["Artwork"].value<QPixmap>();
         emit coverChanged(m_artwork);
+        if(Plasma::ToolTipManager::self()->isVisible(this)) {
+            toolTipAboutToShow();
+        }
     }
 
     update();
 }
 
+void NowPlaying::toolTipAboutToShow()
+{
+    Plasma::ToolTipContent toolTip;
+    if (m_state == Playing || m_state == Paused) {
+        toolTip.setMainText(m_title);
+        toolTip.setSubText(i18nc("song performer, displayed below the song title", "by %1", m_artist));
+        toolTip.setImage(m_artwork.scaled(QSize(50,50),Qt::KeepAspectRatio));
+    } else {
+        toolTip.setMainText(i18n("No current track."));
+    }
+
+    Plasma::ToolTipManager::self()->setContent(this, toolTip);
+}
+
 void NowPlaying::playerAdded(const QString &name)
 {
     kDebug() << "Player" << name << "added";
